<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Norėdami stabdyti įrašinėjimą,
spustelėkite dėklo piktogramą
arba dar kartą paspauskite trumpinį</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Nesukimėkite ekrano per įrašymą</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekraninis nuotrauka</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Įrašymas</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekraninis nuotrauka</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekraninis nuotrauka</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Ekraninė nuotrauka nepavyko.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Fiksuoti ekranines nuotraukas</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Įrašyta į %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Nepaisyti</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Iškarpinė</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Atidaryti aplanką</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Ekraninė nuotrauka baigta ir kopijuota į klipobriašą</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Fiksuoti ekranines nuotraukas</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Ekraninis nuotrauka</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Ekraninis įrašas prasidės %1 sekundėmis</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>Gauti pagalbą.</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Nepavyko pasiimti nuoseklios ekraninės nuotraukos.</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Pasiekta apatine skrydžio sritis</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Įrašomas ekrano failas, prašom laukti...</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Kaip langų efektas yra išjungtas procese, įrašymas turi būti sustabdytas</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ekraninė nuotrauka baigta</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Pasirinkti sritį</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Žiūrėti</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Įrašinėjimas užbaigtas</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Įrašyta į %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Išsaugymas nepavyko. Prašom išsaugoti jį jūsų namų kataloge.</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Pasiekta maksimalus ilgis</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>pritaikykite snaptūros zoną</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Parsvejikite pelės ratuku arba spustelėkite, kad imtumėte lankstomą ekraninį atspvaizdį</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Lėtinkite lankstymo greitį</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Neteisinga zona, spustelėkite, kad </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Įveskite tekstą čia</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Pradėti / Ekraninis atspvaizdis</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Išeiti/Įrašyti</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Greitas pradėjimas</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Langas</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Uždelsti</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Visas ekraninis atspvaizdis</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Stačiakampis</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsė</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linija</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Piešimo žaliuzė</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekstas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Pašalinti</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Padidinti aukštį aukštyn</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Padidinti aukštį žemyn</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Padidinti plotį kairėn</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Padidinti plotį dešinėn</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Sumažinti aukštį aukštyn</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Sumažinti aukštį žemyn</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Sumažinti plotį kairėn</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Sumažinti plotį dešinėn</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rodyti trumpinės</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Garsas</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Klaviatūros žingsnis</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Pradėti įrašinėjimą</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Pradėti/įrašyti</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Pelė</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Įrankiai</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Ištraukti tekstą</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fištografijos</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Pradėti OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Pradėti scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Rodyklė</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekraninis vaizdas</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Įrašyti</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Stačiakampis
Spustelėkite ir laikykite Shift, norėdami nubrėžti kvadratą</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Apvalioji formos
Spustelėkite ir laikykite Shift, norėdami nubrėžti apskritimą</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Piešiklis
Spustelėkite ir laikykite Shift, norėdami nubrėžti tiesią liniją</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Reguliuoti neaiškumą (Nuplukdykite, kad pakeistumėte)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Reguliuoti piešiklio dydį (Nuplukdykite, kad pakeistumėte)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Reguliuoti teksto dydį (Nuplukdykite, kad pakeistumėte)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Spustelėkite ir vilkite,
norėdami pasirinkti
įrašinėjimo sritį</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Rodyti klaviatūros žingsnį (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Slėpti klaviatūros žingsnį (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Rodyti klaviatūros žingsnį (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Įjungti kamerą (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Išjungti kamerą (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekraninis vaizdas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Nustatymai (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formatas:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Garsas</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofonas</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Sistemos garsas</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Rodyklė</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Spustelėjimas</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Išsaugoti į</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Įrašyti į darbalaukį</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Įrašyti į vaizdo įrašus</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Stačiakampis (R)
Spustelėkite ir laikykite Shift, kad nubrėžtumėte kvadratą</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Apvalus (O)
Spustelėkite ir laikykite Shift, kad nubrėžtumėte aptrukimą</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linija (L)
Spustelėkite ir laikykite Shift, kad nubrėžtumėte vertikalią ar horizontalią liniją</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Sėkla (X)
Spustelėkite ir laikykite Shift, kad nubrėžtumėte vertikalią ar horizontalią sėklą</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Akištelė (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Apskritimas (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Tekstas (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Ištraukti tekstą (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Fiksavimas (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Atstatyti (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Iškarpinė</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Vaizdai</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Skrydžių</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Nustatyti kelią išsaugant</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Keisti kelią išsaugant</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatas</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Rėmų efektai</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Žaizda</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Riba</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Įrenginys</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Ištraukti tekstą</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Uždaryti (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>Gerai (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Pareikškite įrašymo zoną viduje %1*%2, kad gautumėte geriau vaizdo efektą</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Ekranų įrašymas šiuo metu nepalaikomas</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Naujas įrašas</translation>
    </message>
</context>
</TS>
